=======
History
=======

0.2.1 (2019-03-22)
------------------
* Add docstrings for all functions
* Add autodocs
* Switch out ``bumpversion`` for ``bump2version``

0.2.0 (2019-03-22)
------------------
* Add Hive function
* Add configuration CLI
* Fix Travis config to Python 3.5+

0.1.0 (2019-02-26)
------------------

* First release on PyPI.
